@@ -2,12 +2,11 @@ package cli
 
 import (
 	"fmt"
+	"time"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
-	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
-	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 
 	"github.com/spf13/cobra"
 )
@@ -16,6 +15,20 @@ var (
 	printOutput bool
 	strict      bool
 	manual      bool
+	debug       bool
+
+	supportedShells = []string{
+		"bash",
+		"zsh",
+		"fish",
+		"powershell",
+		"pwsh",
+		"cmd",
+		"nu",
+		"tcsh",
+		"elvish",
+		"xonsh",
+	}
 
 	initCmd = &cobra.Command{
 		Use:   "init [bash|zsh|fish|powershell|pwsh|cmd|nu|tcsh|elvish|xonsh]",
@@ -23,19 +36,8 @@ var (
 		Long: `Initialize your shell and config.
 
 See the documentation to initialize your shell: https://ohmyposh.dev/docs/installation/prompt.`,
-		ValidArgs: []string{
-			"bash",
-			"zsh",
-			"fish",
-			"powershell",
-			"pwsh",
-			"cmd",
-			"nu",
-			"tcsh",
-			"elvish",
-			"xonsh",
-		},
-		Args: NoArgsOrOneValidArg,
+		ValidArgs: supportedShells,
+		Args:      NoArgsOrOneValidArg,
 		Run: func(cmd *cobra.Command, args []string) {
 			if len(args) == 0 {
 				_ = cmd.Help()
@@ -50,53 +52,40 @@ func init() {
 	initCmd.Flags().BoolVarP(&printOutput, "print", "p", false, "print the init script")
 	initCmd.Flags().BoolVarP(&strict, "strict", "s", false, "run in strict mode")
 	initCmd.Flags().BoolVarP(&manual, "manual", "m", false, "enable/disable manual mode")
+	initCmd.Flags().BoolVar(&debug, "debug", false, "enable/disable debug mode")
 	_ = initCmd.MarkPersistentFlagRequired("config")
 	RootCmd.AddCommand(initCmd)
 }
 
 func runInit(shellName string) {
+	var startTime time.Time
+	if debug {
+		startTime = time.Now()
+	}
+
 	env := &runtime.Terminal{
 		CmdFlags: &runtime.Flags{
 			Shell:  shellName,
 			Config: configFlag,
 			Strict: strict,
 			Manual: manual,
+			Debug:  debug,
 		},
 	}
+
 	env.Init()
 	defer env.Close()
 
 	cfg := config.Load(env)
 
-	shell.Transient = cfg.TransientPrompt != nil
-	shell.ErrorLine = cfg.ErrorLine != nil || cfg.ValidLine != nil
-	shell.Tooltips = len(cfg.Tooltips) > 0
-	shell.ShellIntegration = cfg.ShellIntegration
-	shell.PromptMark = shellName == shell.FISH && cfg.ITermFeatures != nil && cfg.ITermFeatures.Contains(terminal.PromptMark)
-	shell.AutoUpgrade = cfg.AutoUpgrade
+	feats := cfg.Features()
 
-	for i, block := range cfg.Blocks {
-		// only fetch cursor position when relevant
-		if cfg.EnableCursorPositioning && (i == 0 && block.Newline) {
-			shell.CursorPositioning = true
-		}
-
-		if block.Type == config.RPrompt {
-			shell.RPrompt = true
-		}
-	}
-
-	// allow overriding the upgrade notice from the config
-	if cfg.DisableNotice || cfg.AutoUpgrade {
-		env.Cache().Set(upgrade.CACHEKEY, "disabled", -1)
-	}
-
-	if printOutput {
-		init := shell.PrintInit(env)
+	if printOutput || debug {
+		init := shell.PrintInit(env, feats, &startTime)
 		fmt.Print(init)
 		return
 	}
 
-	init := shell.Init(env)
+	init := shell.Init(env, feats)
 	fmt.Print(init)
 }
