@@ -69,21 +69,25 @@ func (e *Engine) canWriteRightBlock(length int, rprompt bool) (int, bool) {
 }
 
 func (e *Engine) pwd() {
-	// only print when supported
-	sh := e.Env.Shell()
-	if sh == shell.ELVISH || sh == shell.XONSH {
-		return
-	}
 	// only print when relevant
 	if len(e.Config.PWD) == 0 && !e.Config.OSC99 {
 		return
 	}
 
-	cwd := e.Env.Pwd()
+	// only print when supported
+	sh := e.Env.Shell()
+	if sh == shell.ELVISH || sh == shell.XONSH {
+		return
+	}
+
+	pwd := e.Env.Pwd()
+	if e.Env.IsCygwin() {
+		pwd = strings.ReplaceAll(pwd, `\`, `/`)
+	}
 
 	// Backwards compatibility for deprecated OSC99
 	if e.Config.OSC99 {
-		e.write(terminal.Pwd(terminal.OSC99, "", "", cwd))
+		e.write(terminal.Pwd(terminal.OSC99, "", "", pwd))
 		return
 	}
 
@@ -100,7 +104,7 @@ func (e *Engine) pwd() {
 
 	user := e.Env.User()
 	host, _ := e.Env.Host()
-	e.write(terminal.Pwd(pwdType, user, host, cwd))
+	e.write(terminal.Pwd(pwdType, user, host, pwd))
 }
 
 func (e *Engine) getNewline() string {
@@ -267,7 +271,7 @@ func (e *Engine) patchPowerShellBleed() {
 	// when in PowerShell, we need to clear the line after the prompt
 	// to avoid the background being printed on the next line
 	// when at the end of the buffer.
-	// See https://githue.com/JanDeDobbeleer/oh-my-posh/issues/65
+	// See https://github.com/JanDeDobbeleer/oh-my-posh/issues/65
 	if e.Env.Shell() != shell.PWSH && e.Env.Shell() != shell.PWSH5 {
 		return
 	}
@@ -518,7 +522,7 @@ func New(flags *runtime.Flags) *Engine {
 	flags.HasTransient = cfg.TransientPrompt != nil
 
 	terminal.Init(env.Shell())
-	terminal.BackgroundColor = shell.ConsoleBackgroundColor(env, cfg.TerminalBackground)
+	terminal.BackgroundColor = cfg.TerminalBackground.ResolveTemplate(env)
 	terminal.Colors = cfg.MakeColors()
 	terminal.Plain = flags.Plain
 
